#!/usr/env/bin python3

from unittest import TestCase, main
import gblur

class TestBlur(TestCase):
    def setUp(self):
        self.radius = 1
    def test_blur(self):
        f = open("tests/cballs.png", "rb")
        buf = f.read()
        f.close()
        img = gblur.blur(buf, self.radius)
        f = open("tests/cballs_blurred.png", "rb")
        good = f.read()
        self.assertEqual(bytearray(img), good)
        f.close()

if __name__ == '__main__':
    main()



import gblur
import time

runs = 6
average = 0.0
for i in range(runs):
    start = time.time()
    f = open("tests/cballs.png", 'rb')
    img = f.read()
    out = gblur.blur(img, radius=1)
    with open("tests/cballs_blurred.png", 'wb') as f:
        f.write(bytearray(out))
    average += (time.time() - start)

average = average / runs
print("Average runtime: %s seconds" % str(average))
